pub struct FunctionalFabric<T>where
T: SimObject + Routable,{ /* private fields */ }Implementations
Sourceimpl<T> FunctionalFabric<T>where
T: SimObject + Routable,
impl<T> FunctionalFabric<T>where
T: SimObject + Routable,
Sourcepub fn new_and_register_with_renames(
engine: &Engine,
clock: &Clock,
parent: &Rc<Entity>,
name: &str,
aka: Option<&Aka>,
config: Rc<FabricConfig>,
) -> Result<Rc<Self>, SimError>
pub fn new_and_register_with_renames( engine: &Engine, clock: &Clock, parent: &Rc<Entity>, name: &str, aka: Option<&Aka>, config: Rc<FabricConfig>, ) -> Result<Rc<Self>, SimError>
Create and register a new fabric.
The total number of ingress/egress ports must be at least two, otherwise there are no valid routes and an error will be returned.
Sourcepub fn new_and_register(
engine: &Engine,
clock: &Clock,
parent: &Rc<Entity>,
name: &str,
config: Rc<FabricConfig>,
) -> Result<Rc<Self>, SimError>
pub fn new_and_register( engine: &Engine, clock: &Clock, parent: &Rc<Entity>, name: &str, config: Rc<FabricConfig>, ) -> Result<Rc<Self>, SimError>
Create and register a new fabric.
The total number of ingress/egress ports must be at least two, otherwise there are no valid routes and an error will be returned.