FabricConfig

Struct FabricConfig 

pub struct FabricConfig { /* private fields */ }
Configuration structure for a fabric

Implementations

Source

impl FabricConfig

pub fn new( num_columns: usize, num_rows: usize, num_ports_per_node: usize, ports_per_node_limit: Option<usize>, cycles_per_hop: usize, cycles_overhead: usize, rx_buffer_bytes: usize, tx_buffer_bytes: usize, port_bits_per_tick: usize, ) -> Self

pub fn max_num_ports(&self) -> usize

Returns the maximum number of ports in the fabric

pub fn num_ports(&self) -> usize

Returns the number of ports in a fabric.

pub fn port_indices(&self) -> &Vec<usize>

Returns the actual port indices

pub fn col_row_port_to_fabric_port_index( &self, col: usize, row: usize, port: usize, ) -> usize

Given a column, row and port index, return the overall index in the fabric ports

Ports laid out as ports[col][row][port]

pub fn fabric_port_index_to_col_row_port( &self, fabric_port_index: usize, ) -> (usize, usize, usize)

pub fn node_num_ingress_egress_ports(&self, col: usize, row: usize) -> usize

pub fn max_x(&self) -> usize

pub fn max_y(&self) -> usize

pub fn num_columns(&self) -> usize

pub fn num_rows(&self) -> usize

pub fn num_ports_per_node(&self) -> usize

pub fn cycles_per_hop(&self) -> usize

pub fn cycles_overhead(&self) -> usize

pub fn port_bits_per_tick(&self) -> usize