pub struct OperatorCustom {
pub name: Option<String>,
pub machine_ops: MachineOpCounts,
}Fields
name: Option<String>machine_ops: MachineOpCountsTrait Implementations
Sourceimpl Clone for OperatorCustom
impl Clone for OperatorCustom
Sourcefn clone(&self) -> OperatorCustom
fn clone(&self) -> OperatorCustom
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OperatorCustom
impl Debug for OperatorCustom
Sourceimpl<'de> Deserialize<'de> for OperatorCustom
impl<'de> Deserialize<'de> for OperatorCustom
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Operator for OperatorCustom
impl Operator for OperatorCustom
Sourcefn validate_tensors(
&self,
_inputs: &[Option<Tensor>],
_outputs: &[Option<Tensor>],
) -> SimResult
fn validate_tensors( &self, _inputs: &[Option<Tensor>], _outputs: &[Option<Tensor>], ) -> SimResult
Validate that the input and output tensors are valid shapes and
datatypes
Sourcefn compute_delay_ticks(
&self,
compute_capabilities: &Rc<ComputeCapabilities>,
_inputs: &[Option<TensorView>],
_outputs: &[Option<TensorView>],
) -> Result<usize, SimError>
fn compute_delay_ticks( &self, compute_capabilities: &Rc<ComputeCapabilities>, _inputs: &[Option<TensorView>], _outputs: &[Option<TensorView>], ) -> Result<usize, SimError>
Returns the number of clock ticks needed to perform the
specified computation give the machine capabilities
Sourcefn compute_machine_ops(
&self,
_inputs: &[Option<TensorView>],
_outputs: &[Option<TensorView>],
) -> Result<MachineOpCounts, SimError>
fn compute_machine_ops( &self, _inputs: &[Option<TensorView>], _outputs: &[Option<TensorView>], ) -> Result<MachineOpCounts, SimError>
Returns the number of machine operations performed by the specified
computation, broken down by operation type.
Sourcefn partition_views(
&self,
input_views: &[Option<TensorView>],
output_views: &[Option<TensorView>],
_num_partitions: usize,
) -> Result<Vec<TensorPartition>, SimError>
fn partition_views( &self, input_views: &[Option<TensorView>], output_views: &[Option<TensorView>], _num_partitions: usize, ) -> Result<Vec<TensorPartition>, SimError>
Partition the operation into one or more views that can be executed in
parallel. Implementations may return fewer than
num_partitions if the
operator cannot be split that finely.Sourcefn compute_flops(
&self,
inputs: &[Option<TensorView>],
outputs: &[Option<TensorView>],
) -> Result<usize, SimError>
fn compute_flops( &self, inputs: &[Option<TensorView>], outputs: &[Option<TensorView>], ) -> Result<usize, SimError>
Returns the total number of FLOPs performed by the specified
computation.