pub struct Tensor { /* private fields */ }Implementations
Sourceimpl Tensor
impl Tensor
pub fn with_id(self, id: impl Into<String>) -> Self
pub fn set_id(&mut self, id: impl Into<String>)
pub fn id(&self) -> Option<&str>
Sourcepub fn num_bytes(&self) -> usize
pub fn num_bytes(&self) -> usize
Return the number of bytes this entire Tensor will consume in memory.
This currently assumes it is optimally packed into memory bytes
pub fn dtype(&self) -> &DataType
pub fn addr(&self) -> u64
pub fn set_addr(&mut self, addr: u64)