ProcessingElementConfig

Struct ProcessingElementConfig 

pub struct ProcessingElementConfig {
    pub num_active_requests: usize,
    pub lsu_access_bytes: usize,
    pub overhead_size_bytes: usize,
    pub sram_bytes: usize,
    pub adds_per_tick: f64,
    pub muls_per_tick: f64,
    pub compares_per_tick: f64,
}

Fields

num_active_requests: usize

The number of outstanding requests can the LSU handle at once

lsu_access_bytes: usize

The maximum number of bytes in each memory access

overhead_size_bytes: usize

The number of bytes of protocol overhead for each memory transaction

sram_bytes: usize

The total number of local SRAM storage bytes available to the PE

adds_per_tick: f64

Number of add operations per tick

muls_per_tick: f64

Number of multiply operations per tick

compares_per_tick: f64

Number of compare operations per tick