Permission

Enum Permission 

pub enum Permission {
    ReadOnly,
    ReadVolatileOnly,
    ReadWrite,
    ReadVolatileWrite,
    WriteCommits,
    WriteOneCommits,
    WriteOnly,
    WriteIgnore,
    Reserved,
}
Register access permissions

Variants



ReadOnly

Writes ignored. Reads return constant value.



ReadVolatileOnly

Writes ignored. Reads return current value of dynamic state.



ReadWrite

Writes value committed to state. Reads return last value written, or reset value if not written yet.



ReadVolatileWrite

Writes value committed to state. Reads return current value of dynamic state.



WriteCommits

Writes value committed to state. Reads return 0.



WriteOneCommits

Writes of 0b1 initiate background operation. Reads return 0.



WriteOnly

Writes value commited to state. Reads not possible. There is no mechanism available to directly read this state. It may be possible to read the state indirectly.



WriteIgnore

All writes ignored. Reads return 0.



Reserved

Writes ignored. Reads return 0.