pub struct ProcessingElementConfig {
pub num_active_requests: usize,
pub lsu_access_bytes: usize,
pub overhead_size_bytes: usize,
pub sram_bytes: usize,
pub adds_per_tick: f64,
pub muls_per_tick: f64,
pub compares_per_tick: f64,
}Fields
num_active_requests: usizeThe number of outstanding requests can the LSU handle at once
lsu_access_bytes: usizeThe maximum number of bytes in each memory access
overhead_size_bytes: usizeThe number of bytes of protocol overhead for each memory transaction
sram_bytes: usizeThe total number of local SRAM storage bytes available to the PE
adds_per_tick: f64Number of add operations per tick
muls_per_tick: f64Number of multiply operations per tick
compares_per_tick: f64Number of compare operations per tick